@@ -4,7 +4,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the licence, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -152,9 +152,15 @@ typedef struct
   HANDLE message_sent_event, message_received_event;
 } WatchThreadState;
 
-G_DECLARE_FINAL_TYPE (GRegistryBackend, g_registry_backend, G, REGISTRY_BACKEND, GSettingsBackend)
+#define G_TYPE_REGISTRY_BACKEND      (g_registry_backend_get_type ())
+#define G_REGISTRY_BACKEND(inst)     (G_TYPE_CHECK_INSTANCE_CAST ((inst),         \
+                                      G_TYPE_REGISTRY_BACKEND, GRegistryBackend))
+#define G_IS_REGISTRY_BACKEND(inst)  (G_TYPE_CHECK_INSTANCE_TYPE ((inst),         \
+                                      G_TYPE_REGISTRY_BACKEND))
 
-struct _GRegistryBackend {
+typedef GSettingsBackendClass GRegistryBackendClass;
+
+typedef struct {
   GSettingsBackend parent_instance;
 
   gchar *base_path;
@@ -166,7 +172,7 @@ struct _GRegistryBackend {
   GNode *cache_root;
 
   WatchThreadState *watch;
-};
+} GRegistryBackend;
 
 G_DEFINE_TYPE_WITH_CODE (GRegistryBackend,
                          g_registry_backend,
@@ -402,7 +408,7 @@ registry_cache_add_item (GNode         *parent,
   item->block_count = 0;
   item->readable = FALSE;
 
-  trace ("\treg cache: adding %s to %s\n",
+  trace ("\tregistry cache: adding %s to %s\n",
          name, ((RegistryCacheItem *)parent->data)->name);
 
   cache_node = g_node_new (item);
@@ -1532,8 +1538,6 @@ registry_watch_key (HKEY   hpath,
 static gboolean
 watch_handler (RegistryEvent *event)
 {
-  guint i;
-
   trace ("Watch handler: got event in %s, items %i.\n", event->prefix, event->items->len);
 
   /* GSettings requires us to NULL-terminate the array. */
@@ -1796,7 +1800,7 @@ watch_thread_function (LPVOID parameter)
            * likely to block (only when changing notification subscriptions).
            */
           event = g_slice_new (RegistryEvent);
-          event->self = g_object_ref (self->owner);
+          event->self = G_REGISTRY_BACKEND (g_object_ref (self->owner));
           event->prefix = g_strdup (prefix);
           event->items = g_ptr_array_new_with_free_func (g_free);
 
